/**
 * EasyBeans
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: MDBXMLBean.java 2569 2008-03-06 18:34:31Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.examples.pool;

import javax.jms.Message;

/**
 * Message Driven Bean that will be configured using XML file.
 * @author Florent BENOIT
 */
public class MDBXMLBean extends AbsMDBBean {

    /**
     * XML counter bean instances.
     */
    private static int nbInstances = 0;

    /**
     * Max for Bean configured by annotation.
     */
    public static final int MAX_INSTANCE_XML = 2;

    /**
     * Constructor.
     */
    public MDBXMLBean() {
        super();
        nbInstances++;
    }

    /**
     * Check instances.
     * @param message - the message passed to the listener
     */
    @Override
    public void onMessage(final Message message) {
        super.onMessage(message);

        // ensure that nb of instances < MAX
        if (getInstances() > MAX_INSTANCE_XML) {
            System.err.println("Error: number of instances has not been limited !");
        } else {
            System.out.println(MDBXMLBean.class.getSimpleName() + ":Number of instances = '" + getInstances() + "', max = '"
                    + MAX_INSTANCE_XML + "'.");
        }
    }

    /**
     * @return the number of instances built.
     */
    @Override
    public int getInstances() {
        return nbInstances;
    }
}
